@@ -1027,8 +1027,8 @@ class Analytics(object):
         exports = [] # list of { provider_name, export_link, temp_fd, temp_path }
         for r in provider_results:
             export_link = r["most_recent_export_link"]
+            provider_name = r["table_provider"]["name"]
             if export_link:
-                provider_name = r["table_provider"]["name"]
                 if (len(providers) == 0) or (provider_name in providers):
                     temp_fd, temp_path = tempfile.mkstemp(prefix=provider_name, suffix=".csv")
                     exports.append({ "provider_name": provider_name,
@@ -1428,16 +1428,43 @@ class Analytics(object):
         """
         Like product_catalog(), but returns only the outputs of data providers.
         """
+        # Complication due to https://github.com/DemystData/demyst-python/issues/740 --
+        #
+        # The full list of /table_providers/latest which we load into
+        # the provider cache does not include descriptions for
+        # attributes of hosted tables.  So we add a special case: For
+        # hosted tables, we load the data from
+        # /table_providers/$ID/provider_latest instead of from the
+        # cache.
         if all_products:
             provider_names = self.__config.all_provider_names()
         result = []
         for provider_name in provider_names:
-            catalog = self.__connectors.product_catalog(provider_name)
-            if catalog:
-                for c in catalog:
-                    self.__collect_outputs(provider_name, c["output"], result, "")
+            # Load hosted_ tables from Manta
+            if provider_name.startswith("hosted_"):
+                output_fields = self.__fetch_provider_output_fields(provider_name)
+                if output_fields:
+                    for f in output_fields:
+                        name = f["log_flattened_name"].replace("[*]", "[]")
+                        result.append(self.__make_row(provider_name, name, "output", f["type"], f["description"]))
+            # Load normal provider tables from provider cache
+            else:
+                catalog = self.__connectors.product_catalog(provider_name)
+                if catalog:
+                    for c in catalog:
+                        self.__collect_outputs(provider_name, c["output"], result, "")
         return self.__shape_dataframe(pd.DataFrame(result))
 
+    def __fetch_provider_output_fields(self, provider_name):
+        id = str(self.__config.provider_name_to_id(provider_name))
+        url = self.__config.get("MANTA_URL") + "table_providers/"+id+"/provider_latest"
+        data = self.__config.auth_get(url).json()
+        if "version" in data:
+            return data["version"]["output_fields"]
+        else:
+            print("No output fields for " + provider_name)
+            return None
+    
     def __collect_outputs(self, provider_name, outputs, result, name_prefix):
         for o in outputs:
             name = name_prefix + (o.get("name") or "unknown")
